@@ -33,6 +33,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from .._jsii import *
 
 import aws_cdk
@@ -60,6 +62,10 @@ class Message:
         :param message_description: Message description.
         :param message_type: Message type as returned from cdk-nag.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(Message.__init__)
+            check_type(argname="argument message_description", value=message_description, expected_type=type_hints["message_description"])
+            check_type(argname="argument message_type", value=message_type, expected_type=type_hints["message_type"])
         self._values: typing.Dict[str, typing.Any] = {
             "message_description": message_description,
             "message_type": message_type,
@@ -100,7 +106,7 @@ class NagResult:
     def __init__(
         self,
         *,
-        messages: typing.Sequence[Message],
+        messages: typing.Sequence[typing.Union[Message, typing.Dict[str, typing.Any]]],
         resource: builtins.str,
     ) -> None:
         '''Nag result.
@@ -108,6 +114,10 @@ class NagResult:
         :param messages: List of messages.
         :param resource: Resource which triggered the message.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(NagResult.__init__)
+            check_type(argname="argument messages", value=messages, expected_type=type_hints["messages"])
+            check_type(argname="argument resource", value=resource, expected_type=type_hints["resource"])
         self._values: typing.Dict[str, typing.Any] = {
             "messages": messages,
             "resource": resource,
@@ -145,13 +155,13 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="aws-prototyping-sdk.pdk_nag.PDK
     def __init__(self) -> None:
         jsii.create(self.__class__, self, [])
 
-    @jsii.member(jsii_name="addResourceSuppressionsByPathNoThrow") # type: ignore[misc]
+    @jsii.member(jsii_name="addResourceSuppressionsByPathNoThrow")
     @builtins.classmethod
     def add_resource_suppressions_by_path_no_throw(
         cls,
         stack: aws_cdk.Stack,
         path: builtins.str,
-        suppressions: typing.Sequence[cdk_nag.NagPackSuppression],
+        suppressions: typing.Sequence[typing.Union[cdk_nag.NagPackSuppression, typing.Dict[str, typing.Any]]],
         apply_to_children: typing.Optional[builtins.bool] = None,
     ) -> None:
         '''Wrapper around NagSuppressions which does not throw.
@@ -161,9 +171,15 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="aws-prototyping-sdk.pdk_nag.PDK
         :param suppressions: list of suppressions to apply.
         :param apply_to_children: whether to apply to children.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(PDKNag.add_resource_suppressions_by_path_no_throw)
+            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
+            check_type(argname="argument path", value=path, expected_type=type_hints["path"])
+            check_type(argname="argument suppressions", value=suppressions, expected_type=type_hints["suppressions"])
+            check_type(argname="argument apply_to_children", value=apply_to_children, expected_type=type_hints["apply_to_children"])
         return typing.cast(None, jsii.sinvoke(cls, "addResourceSuppressionsByPathNoThrow", [stack, path, suppressions, apply_to_children]))
 
-    @jsii.member(jsii_name="app") # type: ignore[misc]
+    @jsii.member(jsii_name="app")
     @builtins.classmethod
     def app(
         cls,
@@ -201,25 +217,31 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="aws-prototyping-sdk.pdk_nag.PDK
 
         return typing.cast("PDKNagApp", jsii.sinvoke(cls, "app", [props]))
 
-    @jsii.member(jsii_name="getStackAccountRegex") # type: ignore[misc]
+    @jsii.member(jsii_name="getStackAccountRegex")
     @builtins.classmethod
     def get_stack_account_regex(cls, stack: aws_cdk.Stack) -> builtins.str:
         '''Returns a stack account regex.
 
         :param stack: stack instance.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(PDKNag.get_stack_account_regex)
+            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackAccountRegex", [stack]))
 
-    @jsii.member(jsii_name="getStackPartitionRegex") # type: ignore[misc]
+    @jsii.member(jsii_name="getStackPartitionRegex")
     @builtins.classmethod
     def get_stack_partition_regex(cls, stack: aws_cdk.Stack) -> builtins.str:
         '''Returns a stack partition regex.
 
         :param stack: stack instance.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(PDKNag.get_stack_partition_regex)
+            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackPartitionRegex", [stack]))
 
-    @jsii.member(jsii_name="getStackPrefix") # type: ignore[misc]
+    @jsii.member(jsii_name="getStackPrefix")
     @builtins.classmethod
     def get_stack_prefix(cls, stack: aws_cdk.Stack) -> builtins.str:
         '''Returns a prefix comprising of a delimited set of Stack Ids.
@@ -228,15 +250,21 @@ class PDKNag(metaclass=jsii.JSIIMeta, jsii_type="aws-prototyping-sdk.pdk_nag.PDK
 
         :param stack: stack instance.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(PDKNag.get_stack_prefix)
+            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackPrefix", [stack]))
 
-    @jsii.member(jsii_name="getStackRegionRegex") # type: ignore[misc]
+    @jsii.member(jsii_name="getStackRegionRegex")
     @builtins.classmethod
     def get_stack_region_regex(cls, stack: aws_cdk.Stack) -> builtins.str:
         '''Returns a stack region regex.
 
         :param stack: stack instance.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(PDKNag.get_stack_region_regex)
+            check_type(argname="argument stack", value=stack, expected_type=type_hints["stack"])
         return typing.cast(builtins.str, jsii.sinvoke(cls, "getStackRegionRegex", [stack]))
 
 
@@ -288,7 +316,7 @@ class PDKNagApp(
     def add_nag_result(
         self,
         *,
-        messages: typing.Sequence[Message],
+        messages: typing.Sequence[typing.Union[Message, typing.Dict[str, typing.Any]]],
         resource: builtins.str,
     ) -> None:
         '''
@@ -372,6 +400,16 @@ class PDKNagAppProps(aws_cdk.AppProps):
 
         :inheritDoc: true
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(PDKNagAppProps.__init__)
+            check_type(argname="argument analytics_reporting", value=analytics_reporting, expected_type=type_hints["analytics_reporting"])
+            check_type(argname="argument auto_synth", value=auto_synth, expected_type=type_hints["auto_synth"])
+            check_type(argname="argument context", value=context, expected_type=type_hints["context"])
+            check_type(argname="argument outdir", value=outdir, expected_type=type_hints["outdir"])
+            check_type(argname="argument stack_traces", value=stack_traces, expected_type=type_hints["stack_traces"])
+            check_type(argname="argument tree_metadata", value=tree_metadata, expected_type=type_hints["tree_metadata"])
+            check_type(argname="argument fail_on_error", value=fail_on_error, expected_type=type_hints["fail_on_error"])
+            check_type(argname="argument fail_on_warning", value=fail_on_warning, expected_type=type_hints["fail_on_warning"])
         self._values: typing.Dict[str, typing.Any] = {}
         if analytics_reporting is not None:
             self._values["analytics_reporting"] = analytics_reporting
